summaryrefslogtreecommitdiffstats
path: root/kftpgrabber/src/widgets/sidebar.h
diff options
context:
space:
mode:
Diffstat (limited to 'kftpgrabber/src/widgets/sidebar.h')
-rw-r--r--kftpgrabber/src/widgets/sidebar.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/kftpgrabber/src/widgets/sidebar.h b/kftpgrabber/src/widgets/sidebar.h
index 4d4f710..60f95ee 100644
--- a/kftpgrabber/src/widgets/sidebar.h
+++ b/kftpgrabber/src/widgets/sidebar.h
@@ -37,23 +37,23 @@
#ifndef KFTPWIDGETSSIDEBAR_H
#define KFTPWIDGETSSIDEBAR_H
-#include <qwidget.h>
-#include <qvaluevector.h>
+#include <ntqwidget.h>
+#include <ntqvaluevector.h>
class KURL;
-class QSignalMapper;
-class QVBox;
+class TQSignalMapper;
+class TQVBox;
namespace KFTPWidgets {
-typedef QValueVector<QWidget*> SidebarList;
+typedef TQValueVector<TQWidget*> SidebarList;
class MultiTabBar;
class MultiTabBarTab;
/**
* This class provides a sidebar. It uses a customised version of KMultiTabBar for
* displaying the actual tabs. It uses a QSignalMapper to map signals from the
* tabs to the actual sidebars.
*
* This class was copied from amaroK (BrowserBar) and modified to support bottom
@@ -62,7 +62,7 @@ class MultiTabBarTab;
* @author amaroK developers
* @author Jernej Kos
*/
-class Sidebar : public QWidget
+class Sidebar : public TQWidget
{
Q_OBJECT
friend class Splitter;
@@ -72,7 +72,7 @@ public:
Bottom
};
- Sidebar(QWidget *parent, Position position);
+ Sidebar(TQWidget *parent, Position position);
~Sidebar();
/**
@@ -86,32 +86,32 @@ public:
* Returns the content box of the sidebar. This should be where the widget, that
* should be resized when the sidebar resizes, should be placed.
*
* @return A QVBox container widget
*/
- QVBox *content() { return m_content; }
+ TQVBox *content() { return m_content; }
/**
* Returns the sidebar by it's name.
*
* @param name The sidebar's name
* @return A QWidget representing the sidebar or NULL if it is not found
*/
- QWidget *sidebar(const QString &name) const;
+ TQWidget *sidebar(const TQString &name) const;
/**
* Returns the sidebar by it's index.
*
* @param index The sidebar's index
* @return A QWidget representing the sidebar or NULL if the index is invalid
*/
- QWidget *sidebar(int index) const { if (index < 0) index = 0; return m_sidebars[index]; }
+ TQWidget *sidebar(int index) const { if (index < 0) index = 0; return m_sidebars[index]; }
/**
* Returns the currently open sidebar.
*
* @return A QWidget representing the current sidebar
*/
- QWidget *currentSidebar() const { return sidebar(m_currentIndex); }
+ TQWidget *currentSidebar() const { return sidebar(m_currentIndex); }
/**
* Adds a new sidebar widget.
@@ -120,18 +120,18 @@ public:
* @param title The title that will be displayed on the tab
* @param icon Name of the icon that will be displayed besides the title
*/
- void addSidebar(QWidget *widget, const QString &title, const QString &icon);
+ void addSidebar(TQWidget *widget, const TQString &title, const TQString &icon);
protected:
virtual void polish();
- virtual bool event(QEvent *e);
+ virtual bool event(TQEvent *e);
public slots:
- void showSidebar(const QString &name) { showSidebar(indexForName(name)); }
+ void showSidebar(const TQString &name) { showSidebar(indexForName(name)); }
void showSidebar(int index) { if (index != m_currentIndex) showHideSidebar(index); }
void showHideSidebar(int);
void closeCurrentSidebar() { showHideSidebar(m_currentIndex); }
private:
- int indexForName(const QString&) const;
- void mouseMovedOverSplitter(QMouseEvent *e);
+ int indexForName(const TQString&) const;
+ void mouseMovedOverSplitter(TQMouseEvent *e);
void adjustWidgetSizes();
uint maxSidebarWidth() const { return width() / 2; }
@@ -140,16 +140,16 @@ private:
Position m_position;
uint m_pos;
- QWidget *m_divider;
- QVBox *m_content;
+ TQWidget *m_divider;
+ TQVBox *m_content;
MultiTabBar *m_tabBar;
- QWidget *m_sidebarBox;
+ TQWidget *m_sidebarBox;
SidebarList m_sidebars;
int m_currentIndex;
int m_lastIndex;
- QSignalMapper *m_mapper;
+ TQSignalMapper *m_mapper;
};
}
@@ -37,23 +37,23 @@
/**
* This class provides a sidebar. It uses a customised version of KMultiTabBar for
- * displaying the actual tabs. It uses a QSignalMapper to map signals from the
+ * displaying the actual tabs. It uses a TQSignalMapper to map signals from the
* tabs to the actual sidebars.
*
@@ -86,32 +86,32 @@ public:
* should be resized when the sidebar resizes, should be placed.
*
- * @return A QVBox container widget
+ * @return A TQVBox container widget
*/
@@ -86,32 +86,32 @@ public:
*
* @param name The sidebar's name
- * @return A QWidget representing the sidebar or NULL if it is not found
+ * @return A TQWidget representing the sidebar or NULL if it is not found
*/
@@ -86,32 +86,32 @@ public:
*
* @param index The sidebar's index
- * @return A QWidget representing the sidebar or NULL if the index is invalid
+ * @return A TQWidget representing the sidebar or NULL if the index is invalid
*/
@@ -86,32 +86,32 @@ public:
* Returns the currently open sidebar.
*
- * @return A QWidget representing the current sidebar
+ * @return A TQWidget representing the current sidebar
*/